@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.19.0";
+our $VERSION = "v0.19.1";
 
 1;
 __END__
@@ -340,6 +340,22 @@ L<https://rxjs.dev/api/operators/mapTo>
         map_to(123),
     )->subscribe($observer);
 
+=item op_merge_map
+
+L<https://rxjs.dev/api/operators/mergeMap>
+
+    # 11, 21, 31, 12, 22, 32, 13, 23, 33
+    rx_of(10, 20, 30)->pipe(
+        op_merge_map(sub ($x) {
+            return rx_interval(1)->pipe(
+                op_map(sub ($y) {
+                    return $x + $y + 1;
+                }),
+                op_take(3),
+            );
+        }),
+    )->subscribe($observer);
+
 =item op_multicast
 
 L<https://rxjs.dev/api/operators/multicast>
